## 4.0.0.0 (2023-01-03)

[stubsabot] Bump singledispatch to 4.0.* (#9447)

Release: https://pypi.org/pypi/singledispatch/4.0.0
Homepage: https://github.com/jaraco/singledispatch
Diff: https://github.com/jaraco/singledispatch/compare/v3.7.0...v4.0.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 381.
 - Total lines of Python code deleted: 266.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 3.7.5.1 (2022-11-15)

Complete singledispatch stub (#9201)

## 3.7.5 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 3.7.4 (2022-04-27)

Drop Python 2 support in third-party stubs (#7703)

## 3.7.3 (2022-02-12)

singledispatch: fix lint (#7178)

Co-authored-by: hauntsaninja <>

Add singledispatchmethod to singledispatch (#6089)

## 3.7.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 3.7.0 (2021-09-19)

Update third-party package versions (#5996)

